@@ -64,6 +64,25 @@ def register(event: str, handler: Callable, exchange=""):
         asyncio.create_task(_bind(event))
 
 
+async def async_register(event: str, handler: Callable, exchange=""):
+    """
+    :param event:
+    :param handler:
+    :param exchange:
+    :return:
+    """
+    global _registry
+
+    event = f"{exchange}/{event}"
+    item = _registry.get(event, {"handlers": set()})
+    item['handlers'].add(handler)
+    _registry[event] = item
+
+    if _started:
+        # in this case, we need manually bind msg, handler with a queue/channel
+        await _bind(event)
+
+
 async def _bind(event: str):
     global _registry, _engine, _sub_conn, _pub_conn
 
@@ -182,18 +201,18 @@ async def start(engine: Engine = Engine.IN_PROCESS, start_server=False, heart_be
 
         import aioredis
 
-        register(_rpc_client_channel, _client_handle_rpc_call)
+        await async_register(_rpc_client_channel, _client_handle_rpc_call)
         if _start_server:
-            register(_rpc_server_channel, _server_rpc_handler)
+            await async_register(_rpc_server_channel, _server_rpc_handler)
 
-        _pub_conn = await aioredis.create_redis(_dsn)
-        _sub_conn = await aioredis.create_redis(_dsn)
+        _pub_conn = await aioredis.create_redis_pool(_dsn)
+        _sub_conn = await aioredis.create_redis_pool(_dsn)
 
         if _heart_beat > 0:
-            register('heartbeat', _on_heart_beat)
+            await async_register('heartbeat', _on_heart_beat)
     else:
-        register(_rpc_client_channel, _client_handle_rpc_call)
-        register(_rpc_server_channel, _server_rpc_handler)
+        await async_register(_rpc_client_channel, _client_handle_rpc_call)
+        await async_register(_rpc_server_channel, _server_rpc_handler)
 
     # bind registered channels
     for channel in _registry.keys():
